@@ -279,7 +279,7 @@ def set_up_screen_tab(*args):
     global content
     content.destroy()
     global update_btn
-    content, update_btn = screen_tab(settings, voc, pending_updates)
+    content = screen_tab(settings, voc)
     grid.attach(content, 1, 0, 1, 1)
 
 
@@ -689,7 +689,7 @@ def save_includes():
     save_list_to_text_file(variables, os.path.join(config_home, "sway/variables"))
 
     # ~/.config/sway/autostart
-    autostart = ["exec rm {}".format(os.path.join(temp_dir(), "nwg-shell-check-update.lock"))]
+    autostart = ["# This content was generated by nwg-shell-config. Do not modify it manually.\n"]
 
     # Kill wlsunset. We will need either to restart it or turn it off
     subprocess.call("pkill -f wlsunset", shell=True, stdout=subprocess.DEVNULL, stderr=subprocess.STDOUT)
@@ -742,8 +742,6 @@ def save_includes():
         cmd_panel += " -s {}".format(preset["panel-css"])
     autostart.append(cmd_panel)
 
-    autostart.append("exec_always nwg-shell-check-updates")
-
     if settings["lockscreen-use-settings"]:
         c_sleep = "timeout {} '{}'".format(settings["sleep-timeout"], settings["sleep-cmd"]) if settings[
             "sleep-cmd"] else ""
